@@ -4,7 +4,7 @@ use warnings;
 
 our ($AUTOLOAD, %SIGRT);
 
-our $VERSION = '1.51';
+our $VERSION = '1.55';
 
 require XSLoader;
 
@@ -234,7 +234,7 @@ sub sprintf {
 }
 
 sub load_imports {
-our %EXPORT_TAGS = (
+my %default_export_tags = (
 
     assert_h =>	[qw(assert NDEBUG)],
 
@@ -268,9 +268,6 @@ our %EXPORT_TAGS = (
 		S_ISBLK S_ISCHR S_ISDIR S_ISFIFO S_ISGID S_ISREG S_ISUID
 		S_IWGRP S_IWOTH S_IWUSR)],
 
-    fenv_h =>	[qw(FE_DOWNWARD FE_TONEAREST FE_TOWARDZERO FE_UPWARD
-                    fegetround fesetround)],
-
     float_h =>	[qw(DBL_DIG DBL_EPSILON DBL_MANT_DIG
 		DBL_MAX DBL_MAX_10_EXP DBL_MAX_EXP
 		DBL_MIN DBL_MIN_10_EXP DBL_MIN_EXP
@@ -299,19 +296,13 @@ our %EXPORT_TAGS = (
 		    LC_MONETARY LC_NUMERIC LC_TIME NULL
 		    localeconv setlocale)],
 
-    math_h => [qw(FP_ILOGB0 FP_ILOGBNAN FP_INFINITE FP_NAN FP_NORMAL
-                  FP_SUBNORMAL FP_ZERO HUGE_VAL INFINITY Inf M_1_PI
-                  M_2_PI M_2_SQRTPI M_E M_LN10 M_LN2 M_LOG10E M_LOG2E M_PI
-                  M_PI_2 M_PI_4 M_SQRT1_2 M_SQRT2 NAN NaN acos acosh
-                  asin asinh atan atanh cbrt ceil copysign cosh erf
-                  erfc exp2 expm1 fabs fdim floor fma fmax fmin fmod
-                  fpclassify frexp hypot ilogb isfinite isgreater
-                  isgreaterequal isinf isless islessequal
-                  islessgreater isnan isnormal isunordered j0 j1 jn
-                  ldexp lgamma log10 log1p log2 logb lrint modf nan
-                  nearbyint nextafter nexttoward pow remainder remquo
-                  rint round scalbn signbit sinh tan tanh tgamma trunc
-                  y0 y1 yn)],
+    math_h =>   [qw(FP_ILOGB0 FP_ILOGBNAN FP_INFINITE FP_NAN FP_NORMAL
+                    FP_SUBNORMAL FP_ZERO
+                    M_1_PI M_2_PI M_2_SQRTPI M_E M_LN10 M_LN2 M_LOG10E M_LOG2E
+                    M_PI M_PI_2 M_PI_4 M_SQRT1_2 M_SQRT2
+                    HUGE_VAL INFINITY NAN
+                    acos asin atan ceil cosh fabs floor fmod
+		    frexp ldexp log10 modf pow sinh tan tanh)],
 
     pwd_h =>	[],
 
@@ -343,7 +334,7 @@ our %EXPORT_TAGS = (
     stdlib_h =>	[qw(EXIT_FAILURE EXIT_SUCCESS MB_CUR_MAX NULL RAND_MAX
 		abort atexit atof atoi atol bsearch calloc div
 		free getenv labs ldiv malloc mblen mbstowcs mbtowc
-		qsort realloc strtod strtol strtold strtoul wcstombs wctomb)],
+		qsort realloc strtod strtol strtoul wcstombs wctomb)],
 
     string_h =>	[qw(NULL memchr memcmp memcpy memmove memset strcat
 		strchr strcmp strcoll strcpy strcspn strerror strlen
@@ -398,18 +389,38 @@ our %EXPORT_TAGS = (
     utime_h =>	[],
 );
 
-# Exporter::export_tags();
+my %other_export_tags = (
+    fenv_h => [qw(
+        FE_DOWNWARD FE_TONEAREST FE_TOWARDZERO FE_UPWARD fegetround fesetround
+    )],
+
+    math_h_c99 => [ @{$default_export_tags{math_h}}, qw(
+        Inf NaN acosh asinh atanh cbrt copysign erf erfc exp2 expm1 fdim fma
+        fmax fmin fpclassify hypot ilogb isfinite isgreater isgreaterequal
+        isinf isless islessequal islessgreater isnan isnormal isunordered j0 j1
+        jn lgamma log1p log2 logb lrint nan nearbyint nextafter nexttoward
+        remainder remquo rint round scalbn signbit tgamma trunc y0 y1 yn
+    )],
+
+    stdlib_h_c99 => [ @{$default_export_tags{stdlib_h}}, 'strtold' ],
+
+    nan_payload => [ qw(getpayload setpayload setpayloadsig issignaling) ],
+);
+
 {
   # De-duplicate the export list: 
-  my %export;
-  @export{map {@$_} values %EXPORT_TAGS} = ();
+  my ( %export, %export_ok );
+  @export   {map {@$_} values %default_export_tags} = ();
+  @export_ok{map {@$_} values   %other_export_tags} = ();
   # Doing the de-dup with a temporary hash has the advantage that the SVs in
   # @EXPORT are actually shared hash key scalars, which will save some memory.
   our @EXPORT = keys %export;
 
   our @EXPORT_OK = (qw(close lchown nice open pipe read sleep times write
 		       printf sprintf),
-		    grep {!exists $export{$_}} keys %reimpl, keys %replacement);
+		    grep {!exists $export{$_}} keys %reimpl, keys %replacement, keys %export_ok);
+
+  our %EXPORT_TAGS = ( %default_export_tags, %other_export_tags );
 }
 
 require Exporter;
